@@ -40,7 +40,7 @@ from ..utils import (
 
 from ..debugging import log
 
-
+import random
 import re
 from requests.exceptions import RequestException
 from json.decoder import JSONDecodeError
@@ -53,6 +53,7 @@ class YouTubeChatDownloader(BaseChatDownloader):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
+        self._initialize_consent()
 
     _NAME = 'youtube.com'
 
@@ -423,25 +424,27 @@ class YouTubeChatDownloader(BaseChatDownloader):
 
                 else:  # is a normal message
                     message_info['message'] += run['text']
+
             elif 'emoji' in run:
                 emoji = run['emoji']
-                emoji_id = emoji['emojiId']
+                emoji_id = emoji.get('emojiId')
 
-                name = emoji['shortcuts'][0]
+                name = multi_get(emoji, 'shortcuts', 0)
 
-                if emoji_id and emoji_id not in message_emotes:
+                if name:
+                    if emoji_id and emoji_id not in message_emotes:
 
-                    # TODO change to remapping?
-                    message_emotes[emoji_id] = {
-                        'id': emoji_id,
-                        'name': name,
-                        'shortcuts': emoji.get('shortcuts'),
-                        'search_terms': emoji.get('searchTerms'),
-                        'images': YouTubeChatDownloader._parse_thumbnails(emoji.get('image', {})),
-                        'is_custom_emoji': emoji.get('isCustomEmoji', False)
-                    }
+                        # TODO change to remapping?
+                        message_emotes[emoji_id] = {
+                            'id': emoji_id,
+                            'name': name,
+                            'shortcuts': emoji.get('shortcuts'),
+                            'search_terms': emoji.get('searchTerms'),
+                            'images': YouTubeChatDownloader._parse_thumbnails(emoji.get('image', {})),
+                            'is_custom_emoji': emoji.get('isCustomEmoji', False)
+                        }
 
-                message_info['message'] += name
+                    message_info['message'] += name
 
             else:
                 # unknown run
@@ -1031,6 +1034,30 @@ class YouTubeChatDownloader(BaseChatDownloader):
             #     }
             # }
 
+    _CONSENT_ID_REGEX = r'PENDING\+(\d+)'
+    # https://github.com/ytdl-org/youtube-dl/blob/a8035827177d6b59aca03bd717acb6a9bdd75ada/youtube_dl/extractor/youtube.py#L251
+
+    def _initialize_consent(self):
+        if self.get_cookie_value('__Secure-3PSID'):
+            return
+
+        consent_id = None
+        consent = self.get_cookie_value('CONSENT')
+
+        if consent:
+            if 'YES' in consent:
+                return
+            consent_id_match = re.search(self._CONSENT_ID_REGEX, consent)
+
+            if consent_id_match:
+                consent_id = consent_id_match.group()
+
+        if not consent_id:
+            consent_id = random.randint(100, 999)
+
+        self.set_cookie_value('.youtube.com', 'CONSENT',
+                              'YES+cb.20210328-17-p0.en+FX+{}'.format(consent_id))
+
     def _get_initial_info(self, url):
         html = self._session_get(url).text
         yt = re.search(self._YT_INITIAL_DATA_RE, html)
@@ -1128,8 +1155,10 @@ class YouTubeChatDownloader(BaseChatDownloader):
             else:
                 # Video exists, but you cannot view chat for some reason
 
-                error_runs = multi_get(conversation_bar, 'conversationBarRenderer', 'availabilityMessage', 'messageRenderer', 'text')
-                error_message = self._parse_runs(error_runs, False)['message'] if error_runs else 'Video does not have a chat replay.'
+                error_runs = multi_get(conversation_bar, 'conversationBarRenderer',
+                                       'availabilityMessage', 'messageRenderer', 'text')
+                error_message = self._parse_runs(error_runs, False)[
+                    'message'] if error_runs else 'Video does not have a chat replay.'
 
                 raise NoChatReplay(error_message)
 
